package com.hw.dms.service;

import java.util.List;
import com.hw.dms.domain.DmsPlanRepairDetail;

/**
 * 检修计划明细Service接口
 *
 * @author Open Platform
 * @date 2024-01-15
 */
public interface IDmsPlanRepairDetailService
{
    /**
     * 查询检修计划明细
     *
     * @param planRepairDetailId 检修计划明细主键
     * @return 检修计划明细
     */
    public DmsPlanRepairDetail selectDmsPlanRepairDetailByPlanRepairDetailId(Long planRepairDetailId);

    /**
     * 查询检修计划明细列表
     *
     * @param dmsPlanRepairDetail 检修计划明细
     * @return 检修计划明细集合
     */
    public List<DmsPlanRepairDetail> selectDmsPlanRepairDetailList(DmsPlanRepairDetail dmsPlanRepairDetail);

    /**
     * 新增检修计划明细
     *
     * @param dmsPlanRepairDetail 检修计划明细
     * @return 结果
     */
    public int insertDmsPlanRepairDetail(DmsPlanRepairDetail dmsPlanRepairDetail);

    /**
     * 修改检修计划明细
     *
     * @param dmsPlanRepairDetail 检修计划明细
     * @return 结果
     */
    public int updateDmsPlanRepairDetail(DmsPlanRepairDetail dmsPlanRepairDetail);

    /**
     * 批量删除检修计划明细
     *
     * @param planRepairDetailIds 需要删除的检修计划明细主键集合
     * @return 结果
     */
    public int deleteDmsPlanRepairDetailByPlanRepairDetailIds(Long[] planRepairDetailIds);

    /**
     * 删除检修计划明细信息
     *
     * @param planRepairDetailId 检修计划明细主键
     * @return 结果
     */
    public int deleteDmsPlanRepairDetailByPlanRepairDetailId(Long planRepairDetailId);

    List<DmsPlanRepairDetail> selectPlanRepairDetailByPlanRepairId(Long planRepairId);

}
